Package: ggtext
Type: Package
Title: Improved Text Rendering Support for 'ggplot2'
Version: 0.2.0
Authors@R: 
    c(
      person(
        given = "Claus O.",
        family = "Wilke",
        role = c("aut"),
        email = "wilke@austin.utexas.edu",
        comment = c(ORCID = "0000-0002-7470-9261")
      ),
      person(
        given = "Brenton M.",
        family = "Wiernik",
        role = c("aut", "cre"),
        email = "brenton@wiernik.org",
        comment = c(ORCID = "0000-0001-9560-6336", Twitter = "@bmwiernik")
      )
    )
Description: A 'ggplot2' extension that enables the rendering of
    complex formatted plot labels (titles, subtitles, facet labels,
    axis labels, etc.). Text boxes with automatic word wrap are also
    supported.
URL: https://wilkelab.org/ggtext/
BugReports: https://github.com/wilkelab/ggtext/issues
License: GPL-2
Depends: R (>= 3.5)
Imports: ggplot2 (>= 3.3.0), grid, gridtext, rlang, scales
Suggests: cowplot, dplyr, glue, knitr, rmarkdown, testthat, vdiffr
Encoding: UTF-8
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-08-26 18:23:23 UTC; brentonw
Author: Claus O. Wilke [aut] (ORCID: <https://orcid.org/0000-0002-7470-9261>),
  Brenton M. Wiernik [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9560-6336>, Twitter: @bmwiernik)
Maintainer: Brenton M. Wiernik <brenton@wiernik.org>
Repository: CRAN
Date/Publication: 2026-08-28 10:30:07 UTC
Built: R 4.5.2; ; 2026-08-28 14:16:02 UTC; unix
