# Generated by roxygen2: do not edit by hand

S3method(element_grob,element_markdown)
S3method(element_grob,element_textbox)
export(GeomRichText)
export(GeomRichtext)
export(GeomTextBox)
export(draw_key_richtext)
export(element_markdown)
export(element_textbox)
export(element_textbox_simple)
export(geom_richtext)
export(geom_textbox)
import(ggplot2)
import(grid)
import(gridtext)
import(rlang)
