#' Improved text rendering support for ggplot2
#'
#' The ggtext package implements both geoms ([geom_richtext()], [geom_textbox()])
#' and theme elements ([element_markdown()], [element_textbox()]) for improved
#' text rendering with ggplot2.
#'
#' @name ggtext
#' @docType package
#' @import grid
#' @import rlang
#' @import gridtext
#' @import ggplot2
NULL
